.. _tutos:

Tutorials
=========

These tutorials are based on `Jupyter notebooks <http://jupyter.org/>`_. You can find the original notebooks
:download:`here <../examples/tuto_basics.ipynb>` and :download:`there <../examples/tuto_bandmath.ipynb>`.

.. toctree::
   :maxdepth: 2

   tutorials/tuto_basics.nblink
   tutorials/tuto_bandmath.nblink
